;; guile-lib
;; Copyright (C) 2004 Andy Wingo <wingo at pobox dot com>

;; This program is free software; you can redistribute it and/or    
;; modify it under the terms of the GNU General Public License as   
;; published by the Free Software Foundation; either version 2 of   
;; the License, or (at your option) any later version.              
;;                                                                  
;; This program is distributed in the hope that it will be useful,  
;; but WITHOUT ANY WARRANTY; without even the implied warranty of   
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    
;; GNU General Public License for more details.                     
;;                                                                  
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, contact:
;;
;; Free Software Foundation           Voice:  +1-617-542-5942
;; 59 Temple Place - Suite 330        Fax:    +1-617-542-2652
;; Boston, MA  02111-1307,  USA       gnu@gnu.org

;;; Commentary:
;;
;;Integration between texinfo and guile's help system. This module does
;;not export any symbols. When it is read, it adds some custom value
;;help handlers (@pxref{(scheme session)}).
;;
;;Both handlers convert texinfo to plain text. The first is for strings
;;marked up with texinfo @@-commands, and the second is for objects
;;whose documentation is already stexi (native scheme).
;;        
;;; Code:

(define-module (texinfo help)
  #:use-module (texinfo plain-text)
  #:use-module (texinfo)
  #:use-module (ice-9 documentation)
  #:use-module (scheme session))

(define (stexi-help-handler value)
  (let ((docs (object-documentation value)))
    (if (list? docs) ;; pretty lame check for stexi, eh...
        (stexi->plain-text docs)
        #f)))

(define (texi-help-handler value)
  (let ((docs (object-documentation value)))
    (if (and (string? docs) (string-index docs #\@)) ;; another lame check
        (stexi->plain-text (texi-fragment->stexi docs))
        #f)))

(add-value-help-handler! texi-help-handler)
(add-value-help-handler! stexi-help-handler)

;;; arch-tag: 20d19866-49f3-43f8-9164-a0bfc5500667
